pub enum StreamState {
Idle,
Link,
Linked(Token),
Unlinked,
Recycle,
}Variants
Idle
Link
the Stream is asking for connection, this will trigger a call to connect
Linked(Token)
the Stream is linked to a Client (note that the client might not be connected)
Unlinked
the Stream was linked to a Client, but the connection closed, the client was removed and this Stream could not be retried (it should be terminated)
Recycle
the Stream is unlinked and can be reused
Implementations