pub struct StreamParts<'a> {
pub window: &'a mut i32,
pub rbuffer: &'a mut Kawa<Checkout>,
pub wbuffer: &'a mut Kawa<Checkout>,
pub received_end_of_stream: &'a mut bool,
pub data_received: &'a mut usize,
pub context: &'a mut HttpContext,
pub metrics: &'a mut SessionMetrics,
}Expand description
This struct allows to mutably borrow the read and write buffers (dependant on the position) as well as the context and metrics of a Stream at the same time
Fields
window: &'a mut i32rbuffer: &'a mut Kawa<Checkout>wbuffer: &'a mut Kawa<Checkout>received_end_of_stream: &'a mut boolTracks whether end_of_stream has been received on the read side of this connection.
data_received: &'a mut usizeTracks total DATA payload bytes received on the read side (for content-length validation).
context: &'a mut HttpContextmetrics: &'a mut SessionMetricsAuto Trait Implementations
impl<'a> Freeze for StreamParts<'a>
impl<'a> !RefUnwindSafe for StreamParts<'a>
impl<'a> Send for StreamParts<'a>
impl<'a> Sync for StreamParts<'a>
impl<'a> Unpin for StreamParts<'a>
impl<'a> UnsafeUnpin for StreamParts<'a>
impl<'a> !UnwindSafe for StreamParts<'a>