Mux

Struct Mux 

pub struct Mux<Front: SocketHandler, L: ListenerHandler + L7ListenerHandler> {
    pub configured_frontend_timeout: Duration,
    pub frontend_token: Token,
    pub frontend: Connection<Front>,
    pub router: Router,
    pub context: Context<L>,
    pub session_ulid: Ulid,
}

Fields

configured_frontend_timeout: Durationfrontend_token: Tokenfrontend: Connection<Front>router: Routercontext: Context<L>session_ulid: Ulid

Per-session correlation ID generated at construction time. Included in every log line emitted from this module so all events for a single frontend connection can be reassembled (independent of the ephemeral per-stream request id used by access logs).

Implementations