prepend_dgram_header

Function prepend_dgram_header 

pub fn prepend_dgram_header(
    payload: &mut Vec<u8>,
    client: SocketAddr,
    backend: SocketAddr,
) -> usize
Prepend the PPv2 DGRAM header to an owned payload in place, returning the header length so the shell can account for the prefix bytes in metrics/logs.