pub struct TcpListenerConfig {
pub address: SocketAddress,
pub public_address: Option<SocketAddress>,
pub expect_proxy: bool,
pub front_timeout: u32,
pub back_timeout: u32,
pub connect_timeout: u32,
pub active: bool,
pub sni_preread_timeout: Option<u32>,
pub sni_preread_max_bytes: Option<u32>,
}Expand description
details of an TCP listener
Fields
address: SocketAddresspublic_address: Option<SocketAddress>expect_proxy: boolfront_timeout: u32client inactive time, in seconds
back_timeout: u32backend server inactive time, in seconds
connect_timeout: u32time to connect to the backend, in seconds
active: boolwether the listener is actively listening on its socket
sni_preread_timeout: Option<u32>Time allowed to receive enough bytes of the TLS ClientHello to read the
SNI extension, in seconds. Only meaningful when at least one SNI-scoped
RequestTcpFrontend targets this listener; a listener with only
no-SNI frontends never prereads and ignores this value.
sni_preread_max_bytes: Option<u32>Maximum number of bytes buffered while prereading the TLS ClientHello
looking for the SNI extension. Only meaningful when at least one
SNI-scoped RequestTcpFrontend targets this listener. Clamped by the
global buffer_size: a value greater than buffer_size is a
configuration error at load time (raise buffer_size instead).
Implementations
Sourceimpl TcpListenerConfig
impl TcpListenerConfig
Sourcepub fn sni_preread_timeout(&self) -> u32
pub fn sni_preread_timeout(&self) -> u32
Returns the value of sni_preread_timeout, or the default value if sni_preread_timeout is unset.
Sourcepub fn sni_preread_max_bytes(&self) -> u32
pub fn sni_preread_max_bytes(&self) -> u32
Returns the value of sni_preread_max_bytes, or the default value if sni_preread_max_bytes is unset.