pub type MuxTls = Mux<FrontRustls, HttpsListener>;Aliased Type
pub struct MuxTls {
pub configured_frontend_timeout: Duration,
pub frontend_token: Token,
pub frontend: Connection<FrontRustls>,
pub router: Router,
pub context: Context<HttpsListener>,
pub session_ulid: Ulid,
}Fields
configured_frontend_timeout: Durationfrontend_token: Tokenfrontend: Connection<FrontRustls>router: Routercontext: Context<HttpsListener>session_ulid: UlidPer-session correlation ID generated at construction time. Included in every log line emitted from this module so all events for a single frontend connection can be reassembled (independent of the ephemeral per-stream request id used by access logs).