Skip to main contentModule testing
Source pub use crate::Protocol;pub use crate::ProxySession;pub use crate::backends::BackendMap;pub use crate::http::HttpProxy;pub use crate::https::HttpsProxy;pub use crate::pool::Pool;pub use crate::server::ListenSession;pub use crate::server::ProxyChannel;pub use crate::server::Server;pub use crate::server::SessionManager;pub use crate::tcp::TcpProxy;
- HttpListenerConfig
- details of an HTTP listener
- HttpsListenerConfig
- details of an HTTPS listener
- Listeners
- Socket addresses and file descriptors of TCP sockets, needed by a Proxy to start listening
- Poll
- Polls for readiness events on all registered values.
- Rc
- A single-threaded reference-counting pointer. ‘Rc’ stands for ‘Reference
Counted’.
- RefCell
- A mutable memory location with dynamically checked borrow rules
- Registry
- Registers I/O resources.
- ScmSocket
- A unix socket specialized for file descriptor passing
- ServerConfig
- Used by a worker to start its server loop.
The defaults should match those of the config module
- ServerParts
- Everything needed to create a Server
- Slab
- Pre-allocated storage for a uniform data type
- TcpListenerConfig
- details of an TCP listener
- Token
- Associates readiness events with
event::Sources. - UnixStream
- A non-blocking Unix stream socket.
- Context
- Provides the
context method for Result. - IntoRawFd
- A trait to express the ability to consume an object and acquire ownership of
its raw file descriptor.
- prebuild_server
- Setup a standalone server, for testing purposes
- provide_port
- Get a unique port for a sozu listener address.
Each call returns a different port, safe for parallel test execution.